@@ -5,9 +5,9 @@ use warnings;
 
 # for both Linux/Win32
 my $has_proc_pid_file
-    = eval "use Proc::PID::File; 1;";    ## no critic (ProhibitStringyEval)
+    = eval 'use Proc::PID::File; 1;';    ## no critic (ProhibitStringyEval)
 my $has_home_dir
-    = eval "use File::HomeDir; 1;";      ## no critic (ProhibitStringyEval)
+    = eval 'use File::HomeDir; 1;';      ## no critic (ProhibitStringyEval)
 if ( $has_proc_pid_file and $has_home_dir ) {
 
     # If already running, then exit
@@ -29,9 +29,9 @@ my $daemon = 0;
 my $worker;
 
 GetOptions(
-    "debug=i"  => \$debug,     # debug
-    "daemon=i" => \$daemon,    # daemon
-    "worker=s" => \$worker
+    'debug=i'  => \$debug,     # debug
+    'daemon=i' => \$daemon,    # daemon
+    'worker=s' => \$worker
 );                             # manually inser a $worker
 
 if ($worker) {
@@ -61,7 +61,7 @@ if ($worker) {
 
         # skip some
         next
-            if ( $worker eq 'Scraper'
+            if ( 'Scraper' eq $worker
             and not $config->{function_on}->{scraper} );
 
         $cron->add_entry( $one->{time}, \&run_worker, $worker );
@@ -87,7 +87,7 @@ sub run_worker {
 sub debug {
     my ($msg) = @_;
 
-    print "$msg \@ " . localtime() . "\n" if ($debug);
+    print "$msg \@ ", localtime() . "\n" if ($debug);
 }
 
 1;
