@@ -20,6 +20,9 @@ use FindBin qw/$Bin/;
 use File::Spec;
 use lib File::Spec->catdir( $FindBin::Bin, '..', '..', 'lib' );
 use Foorum::XUtils qw/config base_path theschwartz/;
+use UNIVERSAL::require;
+
+$|++;
 
 my $client    = theschwartz();
 my $config    = config();
@@ -72,10 +75,7 @@ foreach my $one (
         and not $config->{function_on}->{topic_pdf} );
 
     my $module = "Foorum::TheSchwartz::Worker::$worker";
-    eval "use $module;";    ## no critic (ProhibitStringyEval)
-    if ($@) {
-        die "can't load $module with error: $@\n";
-    }
+    $module->use or die $@;
 
     $client->can_do($module);
 }
