@@ -2,16 +2,18 @@ package Foorum::Action::PathLogger;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
+our $VERSION = '1.001000';
 use base 'Catalyst::Action';
 use Time::HiRes qw( gettimeofday tv_interval );
 use Data::Dumper;
 
+use MRO::Compat;
+
 sub execute {
     my $self = shift;
     my ( $controller, $c ) = @_;
 
-    $self->NEXT::execute(@_);
+    $self->next::method(@_);
 
     my $loadtime = tv_interval( $c->stash->{start_t0}, [gettimeofday] );
     $self->log_path( $c, $loadtime );
