@@ -2,8 +2,8 @@ package Foorum::Controller::Admin::Log;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Controller';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Controller';
 use Foorum::Utils qw/get_page_from_url/;
 use Foorum::Logger qw/%levels/;
 
