@@ -2,8 +2,8 @@ package Foorum::Controller::Admin::Settings;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Controller';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Controller';
 use YAML::XS qw/DumpFile LoadFile/;
 use Foorum::Utils qw/get_server_timezone_diff/;
 
@@ -104,7 +104,7 @@ sub default : Private {
     $c->config($yaml);                        # load in live
 
     DumpFile( $local_yml, $yaml );
-    $c->stash->{thanks} = 1;
+    $c->stash->{st} = 1;
 }
 
 1;
