@@ -2,8 +2,8 @@ package Foorum::Controller::Ajax::Poll;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Controller';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Controller';
 
 sub vote : Local {
     my ( $self, $c ) = @_;
