@@ -2,8 +2,8 @@ package Foorum::Controller::Get;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Controller';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Controller';
 
 # Module Idea:
 # we can't use /print_error in Model/Topic.pm like.
