@@ -2,8 +2,8 @@ package Foorum::Controller::Profile;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Controller';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Controller';
 use Foorum::XUtils qw/theschwartz/;
 use Digest ();
 use Locale::Country::Multilingual;
@@ -178,7 +178,7 @@ sub change_password : Local {
             ->remove( 'forget_password', $user->{user_id} );
     }
 
-    $c->res->redirect('/profile/edit?info=101');
+    $c->res->redirect('/profile/edit?st=101');
 }
 
 sub forget_password : Local {
@@ -221,7 +221,7 @@ sub forget_password : Local {
         }
     );
 
-    $c->res->redirect('/?info=102');
+    $c->res->redirect('/?st=102');
 }
 
 sub change_email : Local {
