@@ -2,8 +2,8 @@ package Foorum::Controller::Register;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Controller';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Controller';
 use Digest ();
 use WWW::Contact;
 
@@ -75,7 +75,7 @@ sub default : Private {
 
     $c->authenticate( { username => $username, password => $password } );
 
-    $c->res->redirect('/?info=103');
+    $c->res->redirect('/?st=103');
 }
 
 sub activation : Local {
