@@ -2,8 +2,8 @@ package Foorum::Controller::Topic;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Controller';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Controller';
 use Foorum::Utils qw/encodeHTML get_page_from_url generate_random_word/;
 use Foorum::XUtils qw/theschwartz/;
 use List::MoreUtils qw/firstidx/;
@@ -209,14 +209,6 @@ sub create : Regex('^forum/(\w+)/topic/new$') {
         }
     );
 
-    # update forum
-    $c->model('DBIC::Forum')->update_forum(
-        $forum_id,
-        {   total_topics => \'total_topics + 1',    #'
-            last_post_id => $topic->topic_id,
-        }
-    );
-
     $c->res->redirect( $forum->{forum_url} . '/topic/' . $topic->topic_id );
 }
 
