@@ -2,8 +2,8 @@ package Foorum::Model::Log;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Model';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Model';
 use Foorum::Logger qw/error_log/;
 
 sub log_action {
