@@ -2,8 +2,8 @@ package Foorum::Model::Policy;
 
 use strict;
 use warnings;
-our $VERSION = '1.000007';
-use base 'Catalyst::Model';
+our $VERSION = '1.001000';
+use parent 'Catalyst::Model';
 
 sub fill_user_role {
     my ( $self, $c, $field ) = @_;
